@@ -15,19 +15,17 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id: graphviz.ml,v 1.4 2006-05-09 10:19:37 conchon Exp $ *)
-
 (** Interface with {i GraphViz}
 
     This module provides a basic interface with dot and neato,
     two programs of the GraphViz toolbox.
     These tools are available at the following URLs:
       http://www.graphviz.org/
-      http://www.research.att.com/sw/tools/graphviz/
-
- *)
+      http://www.research.att.com/sw/tools/graphviz/ *)
 
 open Format
+open Pervasives (* for compatibility with ocaml 3.12.0+dev17
+		   (incoming ocaml3.12) *)
 
 (***************************************************************************)
 (** {2 Common stuff} *)
@@ -59,7 +57,7 @@ let fprint_string_user ppf s =
     fprintf ppf "\"%s\"" s
 
 type arrow_style =
-  [ `None | `Normal | `Inv | `Dot | `Odot | `Invdot | `Invodot ] 
+  [ `None | `Normal | `Inv | `Dot | `Odot | `Invdot | `Invodot ]
 
 let fprint_arrow_style ppf = function
     `None -> fprintf ppf "none"
@@ -83,7 +81,7 @@ module type ATTRIBUTES = sig
 
   type edge   (** Attributes of edges. *)
 
-  (** Attributes of (optional) boxes around vertices. *) 
+  (** Attributes of (optional) boxes around vertices. *)
   type subgraph = {
     sg_name : string;            (** Box name. *)
     sg_attributes : vertex list; (** Box attributes. *)
@@ -118,7 +116,7 @@ module CommonAttributes = struct
     | `OrderingOut
         (** Constrains  order of out-edges in a subgraph according to
           their file sequence *)
-    ] 
+    ]
 
   (** Attributes of nodes. *)
   type vertex =
@@ -138,7 +136,7 @@ module CommonAttributes = struct
         (** Sets the label printed in the node. The string may include escaped
             newlines [\n], [\l], or [\r] for center, left, and right justified
 	    lines.
-            Record labels may contain recursive box lists delimited by { | }. 
+            Record labels may contain recursive box lists delimited by { | }.
 	*)
     | `Orientation of float
         (** Node rotation angle, in degrees.  Default value is [0.0]. *)
@@ -159,7 +157,7 @@ module CommonAttributes = struct
             simultaneously. *)
     | `Width of float
         (** Sets the minimum width.  Default value is [0.75]. *)
-    ]     
+    ]
 
   (** Attributes of edges. *)
   type edge =
@@ -167,7 +165,7 @@ module CommonAttributes = struct
         (** Sets the edge stroke color.  Default value is [black]. *)
     | `Decorate of bool
         (** If [true], draws a line connecting labels with their edges. *)
-    | `Dir of [ `Forward | `Back | `Both | `None ] 
+    | `Dir of [ `Forward | `Back | `Both | `None ]
         (** Sets arrow direction.  Default value is [`Forward]. *)
     | `Fontcolor of color
         (** Sets the label font color.  Default value is [black]. *)
@@ -187,12 +185,12 @@ module CommonAttributes = struct
         (** Sets the font family name for head and tail labels.  Default
             value is ["Times-Roman"]. *)
     | `Labelfontsize of int
-        (** Sets the font size for head and tail labels (in points). 
+        (** Sets the font size for head and tail labels (in points).
             Default value is [14]. *)
     | `Style of [ `Solid | `Dashed | `Dotted | `Bold | `Invis ]
         (** Sets the layout style of the edge.  Several styles may be combined
             simultaneously. *)
-    ]     
+    ]
 
   (** Pretty-print. *)
 
@@ -244,7 +242,7 @@ module CommonAttributes = struct
     | `Style a -> fprintf ppf "style=%a" fprint_node_style a
     | `Width f -> fprintf ppf "width=%f" f
 
-  let fprint_edge_style = 
+  let fprint_edge_style =
     fprint_node_style
 
   let fprint_arrow_direction ppf = function
@@ -262,7 +260,7 @@ module CommonAttributes = struct
     | `Fontsize i -> fprintf ppf "fontsize=%i" i
     | `Label s -> fprintf ppf "label=%a" fprint_string_user s
     | `Labelfontcolor a -> fprintf ppf "labelfontcolor=%a" fprint_color a
-    | `Labelfontname s -> fprintf ppf "labelfontname=\"%s\"" s 
+    | `Labelfontname s -> fprintf ppf "labelfontname=\"%s\"" s
 	(* (String.escaped s) *)
     | `Labelfontsize i -> fprintf ppf "labelfontsize=%i" i
     | `Style a -> fprintf ppf "style=%a" fprint_edge_style a
@@ -277,13 +275,13 @@ end
 module type ENGINE = sig
 
   module Attributes : sig
-    include ATTRIBUTES 
+    include ATTRIBUTES
     val fprint_graph:formatter -> graph -> unit
     val fprint_vertex: formatter -> vertex -> unit
     val fprint_edge: formatter -> edge -> unit
   end
 
-  (** The litteral name of the engine. *)      
+  (** The litteral name of the engine. *)
   val name: string
 
   (** The keyword for graphs ("digraph" for dot, "graph" for neato) *)
@@ -304,7 +302,7 @@ module MakeEngine
      type t
      module V : sig type t end
      module E : sig type t val src : t -> V.t val dst : t -> V.t end
-       
+
      val iter_vertex : (V.t -> unit) -> t -> unit
      val iter_edges_e : (E.t -> unit) -> t -> unit
 
@@ -327,16 +325,16 @@ struct
   exception Error of string
 
   let handle_error f arg =
-    try 
+    try
       f arg
-    with 
+    with
 	Error msg ->
 	  Printf.eprintf "%s: %s failure\n   %s\n"
 	  Sys.argv.(0) EN.name msg;
 	  flush stderr;
 	  exit 2
 
-    (** [fprint_graph_attributes ppf list] pretty prints a list of 
+    (** [fprint_graph_attributes ppf list] pretty prints a list of
         graph attributes on the formatter [ppf].  Attributes are separated
         by a ";". *)
     let fprint_graph_attributes ppf list =
@@ -344,7 +342,7 @@ struct
 	 fprintf ppf "%a;@ " EN.Attributes.fprint_graph att
        ) list
 
-   (** [fprint_graph_attribute printer ppf list] pretty prints a list of 
+   (** [fprint_graph_attribute printer ppf list] pretty prints a list of
        attributes on the formatter [ppf], using the printer [printer] for
        each attribute.  The list appears between brackets and attributes
        are speparated by ",".  If the list is empty, nothing is printed. *)
@@ -354,7 +352,7 @@ struct
 	  let rec fprint_attributes_rec ppf = function
 	      [] -> ()
 	    | hd' :: tl' ->
-		fprintf ppf ",@ %a%a" 
+		fprintf ppf ",@ %a%a"
 		  fprint_attribute hd'
 		  fprint_attributes_rec tl'
 	  in
@@ -362,12 +360,12 @@ struct
 	    fprint_attribute hd
 	    fprint_attributes_rec tl
 
-    (** [fprint_graph_attributes ppf list] pretty prints a list of 
+    (** [fprint_graph_attributes ppf list] pretty prints a list of
         node attributes using the format of [fprint_attributes]. *)
-    let fprint_node_attributes ppf list = 
+    let fprint_node_attributes ppf list =
       fprint_attributes EN.Attributes.fprint_vertex ppf list
-	 
-    (** [fprint_graph_attributes ppf list] pretty prints a list of 
+
+    (** [fprint_graph_attributes ppf list] pretty prints a list of
         edge attributes using the format of [fprint_attributes]. *)
     let fprint_edge_attributes ppf list =
       fprint_attributes EN.Attributes.fprint_edge ppf list
@@ -375,7 +373,7 @@ struct
     (** [fprint_graph ppf graph] pretty prints the graph [graph] in
         the CGL language on the formatter [ppf]. *)
     let fprint_graph ppf graph =
-      let subgraphs = Hashtbl.create 7 in 
+      let subgraphs = Hashtbl.create 7 in
 
       (* Printing nodes. *)
 
@@ -383,61 +381,61 @@ struct
 
 	let default_node_attributes = X.default_vertex_attributes graph in
 	if default_node_attributes  <> [] then
-	  fprintf ppf "node%a;@ " 
+	  fprintf ppf "node%a;@ "
 	    fprint_node_attributes default_node_attributes;
 
-	X.iter_vertex 
+	X.iter_vertex
           (function node ->
-             begin match X.get_subgraph node with 
+             begin match X.get_subgraph node with
              | None -> ()
-             | Some sg -> 
-                 try 
-                   let (sg,nodes) = 
-		     Hashtbl.find subgraphs sg.EN.Attributes.sg_name 
+             | Some sg ->
+                 try
+                   let (sg,nodes) =
+		     Hashtbl.find subgraphs sg.EN.Attributes.sg_name
 		   in
-                   Hashtbl.replace subgraphs 
+                   Hashtbl.replace subgraphs
 		     sg.EN.Attributes.sg_name (sg,node::nodes)
-                 with Not_found -> 
-                   Hashtbl.add subgraphs sg.EN.Attributes.sg_name (sg,[node]) 
+                 with Not_found ->
+                   Hashtbl.add subgraphs sg.EN.Attributes.sg_name (sg,[node])
              end;
-	     fprintf ppf "%s%a;@ " 
+	     fprintf ppf "%s%a;@ "
 	       (X.vertex_name node)
-	       fprint_node_attributes (X.vertex_attributes node)) 
+	       fprint_node_attributes (X.vertex_attributes node))
           graph
 
       in
 
       (* Printing subgraphs *)
 
-      let print_subgraphs ppf = 
+      let print_subgraphs ppf =
 
         Hashtbl.iter
-          (fun name (sg,nodes) -> 
+          (fun name (sg,nodes) ->
              fprintf ppf "@[<v 2>subgraph cluster_%s { %t%t };@]@\n"
                name
-               
-               (fun ppf -> 
-                  (List.iter 
-                     (fun n -> 
+
+               (fun ppf ->
+                  (List.iter
+                     (fun n ->
 			fprintf ppf "%a;@\n" EN.Attributes.fprint_vertex n)
                      sg.EN.Attributes.sg_attributes))
 
-               (fun ppf -> 
-                  (List.iter 
+               (fun ppf ->
+                  (List.iter
 		     (fun n -> fprintf ppf "%s;" (X.vertex_name n))
                      nodes))
           )
-          subgraphs 
-        
+          subgraphs
+
       in
 
       (* Printing edges *)
 
       let print_edges ppf =
-	
+
 	let default_edge_attributes = X.default_edge_attributes graph in
 	if default_edge_attributes <> [] then
-	  fprintf ppf "edge%a;@ " 
+	  fprintf ppf "edge%a;@ "
 	    fprint_edge_attributes default_edge_attributes;
 
 	X.iter_edges_e (function edge ->
@@ -521,7 +519,7 @@ module DotAttributes = struct
 	    Default value is [8]. *)
     | `Url of string
         (** URL associated with graph (format-dependent). *)
-    ] 
+    ]
 
   (** Attributes of nodes.  They include all common node attributes and
       several specific ones.  All attributes described in the "dot User's
@@ -548,7 +546,7 @@ module DotAttributes = struct
 	    Distiller 3.0 and up. *)
     | `Z of float
         (** z coordinate for VRML output. *)
-    ] 
+    ]
 
   (** Attributes of edges.  They include all common edge attributes and
       several specific ones.  All attributes described in the "dot User's
@@ -565,7 +563,7 @@ module DotAttributes = struct
     | `Comment of string
         (** Comment string. *)
     | `Constraints of bool
-        (** If [false], causes an edge to be ignored for rank assignment. 
+        (** If [false], causes an edge to be ignored for rank assignment.
             Default value is [true]. *)
     | `Headlabel of string
         (** Sets the label attached to the head arrow. *)
@@ -574,13 +572,13 @@ module DotAttributes = struct
     | `Headurl of string
         (** Url attached to head label if output format is ismap. *)
     | `Labelangle of float
-        (** Angle in degrees which head or tail label is rotated off edge. 
+        (** Angle in degrees which head or tail label is rotated off edge.
             Default value is [-25.0]. *)
     | `Labeldistance of float
-        (** Scaling factor for distance of head or tail label from node. 
+        (** Scaling factor for distance of head or tail label from node.
             Default value is [1.0]. *)
     | `Labelfloat of bool
-        (** If [true], lessen constraints on edge label placement. 
+        (** If [true], lessen constraints on edge label placement.
             Default value is [false]. *)
     | `Layer of string
         (** Overlay. *)
@@ -601,7 +599,7 @@ module DotAttributes = struct
     | `Weight of int
         (** Sets the integer cost of stretching the edge.  Default value is
             [1]. *)
-    ] 
+    ]
 
     type subgraph = {
       sg_name : string;
@@ -641,7 +639,7 @@ module DotAttributes = struct
       | `Url s -> fprintf ppf "URL=\"%s\"" s (*(String.escaped s)*)
 
     let fprint_vertex ppf = function
-	#CommonAttributes.vertex as att -> 
+	#CommonAttributes.vertex as att ->
 	  CommonAttributes.fprint_vertex ppf att
       | `Comment s -> fprintf ppf "comment=%a" fprint_string s
       | `Distortion f -> fprintf ppf "distortion=%f" f
@@ -707,7 +705,7 @@ module type GraphWithDotAttrs = sig
 	   attributes. *)
 end
 
-module Dot = 
+module Dot =
   MakeEngine (struct
 		module Attributes = DotAttributes
 		let name = "dot"
@@ -738,9 +736,9 @@ module NeatoAttributes = struct
 	(** [true] makes edge splines if nodes don't overlap.
 	    Default value is [false]. *)
     | `Sep of float
-	(** Edge spline separation factor from nodes.  Default value 
+	(** Edge spline separation factor from nodes.  Default value
 	    is [0.0]. *)
-    ] 
+    ]
 
   (** Attributes of nodes.  They include all common node attributes and
       several specific ones.  All attributes described in the "Neato User's
@@ -749,7 +747,7 @@ module NeatoAttributes = struct
     [ CommonAttributes.vertex
     | `Pos of float * float
         (** Initial coordinates of the node. *)
-    ] 
+    ]
 
   (** Attributes of edges.  They include all common edge attributes and
       several specific ones.  All attributes described in the "Neato User's
@@ -762,7 +760,7 @@ module NeatoAttributes = struct
         (** Preferred length of edge.  Default value is [1.0]. *)
     | `Weight of float
         (** Strength of edge spring.  Default value is [1.0]. *)
-    ] 
+    ]
 
     type subgraph = {
       sg_name : string;
@@ -780,7 +778,7 @@ module NeatoAttributes = struct
       | `Sep f -> fprintf ppf "sep=%f" f
 
     let fprint_vertex ppf = function
-	#CommonAttributes.vertex as att -> 
+	#CommonAttributes.vertex as att ->
 	  CommonAttributes.fprint_vertex ppf att
       | `Pos (f1, f2) -> fprintf ppf "pos=\"%f,%f\"" f1 f2
 
@@ -792,10 +790,16 @@ module NeatoAttributes = struct
 
 end
 
-module Neato = 
+module Neato =
   MakeEngine (struct
 		module Attributes = NeatoAttributes
 		let name = "neato"
 		let opening = "graph"
 		let edge_arrow = "--"
 	      end)
+
+(*
+Local Variables:
+compile-command: "make -C .."
+End:
+*)
