@@ -1,7 +1,7 @@
 (**************************************************************************)
 (*                                                                        *)
 (*  Ocamlgraph: a generic graph library for OCaml                         *)
-(*  Copyright (C) 2004-2008                                               *)
+(*  Copyright (C) 2004-2010                                               *)
 (*  Sylvain Conchon, Jean-Christophe Filliatre and Julien Signoles        *)
 (*                                                                        *)
 (*  This software is free software; you can redistribute it and/or        *)
@@ -25,10 +25,12 @@ module type S = sig
   (** Imperative Unlabeled Graphs *)
   module Concrete (V: COMPARABLE) : 
     Sig.I with type V.t = V.t and type V.label = V.t and type E.t = V.t * V.t
+	  and type E.label = unit
 
   (** Abstract Imperative Unlabeled Graphs *)
   module Abstract(V: sig type t end) : 
     Sig.IM with type V.label = V.t and type E.label = unit
+	   and type E.label = unit
 
   (** Imperative Labeled Graphs *)
   module ConcreteLabeled (V: COMPARABLE)(E: ORDERED_TYPE_DFT) :
@@ -133,6 +135,29 @@ module Digraph = struct
       end
   end
 
+  module ConcreteBidirectionalLabeled(V:COMPARABLE)(E:ORDERED_TYPE_DFT) = struct
+    include I.Digraph.ConcreteBidirectionalLabeled(V)(E)
+    let add_vertex g v =
+      if not (HM.mem v g) then ignore (unsafe_add_vertex g v)
+
+    let add_edge g v1 v2 =
+      add_vertex g v1;
+      add_vertex g v2;
+      ignore (unsafe_add_edge g v1 v2)
+
+    let add_edge_e g (v1, l, v2) =
+      add_vertex g v1;
+      add_vertex g v2;
+      ignore (unsafe_add_edge_e g (v1, l, v2))
+
+    let remove_vertex g v =
+      if HM.mem v g then begin
+        iter_pred_e (fun e -> ignore (remove_edge_e g e)) g v;
+        iter_succ_e (fun e -> ignore (remove_edge_e g e)) g v;
+        ignore (HM.remove v g)
+      end
+  end
+
   module Abstract(V: sig type t end) = struct
     
     include I.Digraph.Abstract(AbstractVertex(V))
@@ -366,7 +391,7 @@ module Matrix = struct
     let create ?size () = 
       failwith 
 	"[ocamlgraph] do not use Matrix.create; please use Matrix.make instead"
-		      
+
     let make n =
       if n < 0 then invalid_arg "[ocamlgraph] Matrix.make";
       Array.init n (fun _ -> Bitv.create n false)
@@ -397,6 +422,9 @@ module Matrix = struct
 				  
     let remove_vertex g _ = ()
     let add_vertex g _ = ()
+		      
+    let clear g = 
+      Array.iter (fun b -> Bitv.iteri (fun j _ -> Bitv.set b j false) b) g
 			   
     let copy g = Array.init (nb_vertex g) (fun i -> Bitv.copy g.(i))
 		   
