@@ -269,7 +269,7 @@ module Dijkstra = struct
     let () = test g v1 v5 60 3
     let () = test g v1 v1 0 0
     let () = if G.is_directed then test_not_found g v5 v1
-    let () = if G.is_directed then assert (not (Dfs.has_cycle g))
+    let () = assert (not (Dfs.has_cycle g))
     let gc = B.add_edge_e g (G.E.create v5 10 v1)
     let v6 = G.V.create 6
     let gc = B.add_vertex gc v6
